<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>NetFileChooseEdit</name>
    <message>
        <source>All files (*)</source>
        <translation>Wszystkie pliki (*)</translation>
    </message>
</context>
<context>
    <name>NetPasswordEdit</name>
    <message>
        <source>Required</source>
        <translation>Wymagane</translation>
    </message>
</context>
<context>
    <name>NetUtils</name>
    <message>
        <source>Off</source>
        <translation>Wyłączony</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Połączono</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Konflikt IP</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Łączenie</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Uzyskiwanie adresu</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Uwierzytelnianie</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Rozłączono</translation>
    </message>
</context>
<context>
    <name>PageAirplane</name>
    <message>
        <source>Airplane mode</source>
        <translation>Tryb samolotowy</translation>
    </message>
    <message>
        <source>Stop wireless communication</source>
        <translation>Zakończ połączenie bezprzewodowe</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation>Włączenie trybu samolotowego wyłączy sieć bezprzewodową, osobisty Hotspot i Bluetooth</translation>
    </message>
</context>
<context>
    <name>PageAppProxy</name>
    <message>
        <source>Application Proxy</source>
        <translation>Proxy aplikacji</translation>
    </message>
    <message>
        <source>Set up proxy servers</source>
        <translation>Konfiguruj serwery proxy</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Typ proxy</translation>
    </message>
    <message>
        <source>http</source>
        <translation>http</translation>
    </message>
    <message>
        <source>socks4</source>
        <translation>socks4</translation>
    </message>
    <message>
        <source>socks5</source>
        <translation>socks5</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Adres IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Wymagane</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Nieprawidłowy adres IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Nieprawidłowy port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nazwa użytkownika</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Opcjonalne</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Zaznacz „Użyj proxy” w menu kontekstowym aplikacji programu wywołującego po skonfigurowaniu</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
</context>
<context>
    <name>PageDSL</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>Set up a dial-up network connection</source>
        <translation>Ustaw połączenie wdzwaniane</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Rozłącz</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Połącz</translation>
    </message>
    <message>
        <source>Add PPPoE connection</source>
        <translation>Dodaj połączenie PPPoE</translation>
    </message>
</context>
<context>
    <name>PageDSLSettings</name>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Czy na pewno chcesz usunąć tę konfigurację?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <source>%1 Network Properties</source>
        <translation>%1 Ustawienia sieci</translation>
    </message>
</context>
<context>
    <name>PageDetails</name>
    <message>
        <source>Network Details</source>
        <translation>Szczegóły sieci</translation>
    </message>
    <message>
        <source>View all network configurations</source>
        <translation>Wyświetl wszystkie konfiguracje sieci</translation>
    </message>
    <message>
        <source>Details has been copied</source>
        <translation>Skopiowano informacje do schowka</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Zaznacz wszystko</translation>
    </message>
    <message>
        <source>Network Detection</source>
        <translation>Wykrywanie sieci</translation>
    </message>
</context>
<context>
    <name>PageHotspot</name>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Brak</translation>
    </message>
    <message>
        <source>2.4 GHz</source>
        <translation>2.4 GHz</translation>
    </message>
    <message>
        <source>5 GHz</source>
        <translation>5 GHz</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatycznie</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Nie przypisano</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Osobisty Hotspot</translation>
    </message>
    <message>
        <source>Share the network</source>
        <translation>Udostępnij sieć</translation>
    </message>
    <message>
        <source>My Hotspot</source>
        <translation>Mój Hotspot</translation>
    </message>
    <message>
        <source>Edit My Hotspot</source>
        <translation>Edytuj mój Hotspot</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Nazwa (SSID)</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Wymagane</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Bezpieczeństwo</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Pasmo</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <source>Shared Settings</source>
        <translation>Ustawienia współdzielenia</translation>
    </message>
    <message>
        <source>Hotspot Sharing Device</source>
        <translation>Udostępnianie urządzenia Hotspot</translation>
    </message>
    <message>
        <source>If you want to use the personal hotspot, disable Airplane Mode first and then enable the wireless network adapter.</source>
        <translation>Jeśli chcesz korzystać z osobistego Hotspota, najpierw wyłącz Tryb samolotowy i włącz bezprzewodową kartę sieciową.</translation>
    </message>
    <message>
        <source>If you want to use the personal hotspot, disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first and then enable the wireless network adapter.</source>
        <translation>Jeśli chcesz korzystać z osobistego Hotspota, najpierw wyłącz &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Tryb samolotowy&lt;/a&gt; i włącz bezprzewodową kartę sieciową.</translation>
    </message>
    <message>
        <source>Enable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network&apos;&gt;Wireless Network Adapter&lt;/a&gt; first if you want to use the personal hotspot.</source>
        <translation>Najpierw włącz &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network&apos;&gt;Bezprzewodową kartę sieciową&lt;/a&gt;, jeśli chcesz korzystać z Hotspota osobistego.</translation>
    </message>
</context>
<context>
    <name>PageSettings</name>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Czy na pewno chcesz usunąć tę konfigurację?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <source>%1 Network Properties</source>
        <translation>%1 Ustawienia sieci</translation>
    </message>
</context>
<context>
    <name>PageSystemProxy</name>
    <message>
        <source>System Proxy</source>
        <translation>Proxy systemowe</translation>
    </message>
    <message>
        <source>Set up proxy servers</source>
        <translation>Konfiguruj serwery proxy</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Typ proxy</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatycznie</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ręcznie</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Adres URL konfiguracji</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Wymagane</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>Proxy HTTP</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>Proxy HTTPS</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>Proxy FTP</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>Proxy SOCKS</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Ignoruj konfiguracje proxy dla powyższych hostów i domen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
</context>
<context>
    <name>PageVPN</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Connect, add, import</source>
        <translation>Połącz, dodaj, importuj</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Rozłącz</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Połącz</translation>
    </message>
    <message>
        <source>Add VPN</source>
        <translation>Dodaj VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importuj VPN</translation>
    </message>
    <message>
        <source>*.conf</source>
        <translation>*.conf</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Błąd importu</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Błąd pliku</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>PageVPNSettings</name>
    <message>
        <source>VPN Type</source>
        <translation>Typ VPN</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Czy na pewno chcesz usunąć tę konfigurację?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Eksportuj</translation>
    </message>
    <message>
        <source>*.conf</source>
        <translation>*.conf</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <source>%1 Network Properties</source>
        <translation>%1 Ustawienia sieci</translation>
    </message>
</context>
<context>
    <name>PageWiredDevice</name>
    <message>
        <source>Connect, edit network settings</source>
        <translation>Połącz, edytuj ustawienia sieci</translation>
    </message>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Najpierw podłącz kabel sieciowy</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Rozłącz</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Połącz</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Dodaj połączenie sieciowe</translation>
    </message>
</context>
<context>
    <name>PageWirelessDevice</name>
    <message>
        <source>Connect, edit network settings</source>
        <translation>Połącz, edytuj ustawienia sieci</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Rozłącz</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Połącz</translation>
    </message>
    <message>
        <source>Other Networks</source>
        <translation>Inne sieci</translation>
    </message>
    <message>
        <source>Disable Airplane Mode first if you want to connect to a wireless network</source>
        <translation>Najpierw wyłącz Tryb samolotowy, jeśli chcesz połączyć się z siecią bezprzewodową</translation>
    </message>
    <message>
        <source>Disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>Najpierw wyłącz &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Tryb samolotowy&lt;/a&gt;, aby połączyć się z siecią bezprzewodową</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Najpierw wyłącz Hotspot, aby połączyć się z siecią bezprzewodową</translation>
    </message>
    <message>
        <source>&lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;Disable hotspot&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>Najpierw &lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;wyłącz Hotspot&lt;/a&gt;, aby połączyć się z siecią bezprzewodową</translation>
    </message>
    <message>
        <source>My Networks</source>
        <translation>Moje sieci</translation>
    </message>
</context>
<context>
    <name>SectionDNS</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Gotowe</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Edytuj</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Nieprawidłowy adres IP</translation>
    </message>
</context>
<context>
    <name>SectionDevice</name>
    <message>
        <source>Not Bind</source>
        <translation>Nie przypisano</translation>
    </message>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Adres MAC urządzenia</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Sklonowany adres MAC</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Dostosuj MTU</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Pasmo</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatycznie</translation>
    </message>
    <message>
        <source>2.4 GHz</source>
        <translation>2.4 GHz</translation>
    </message>
    <message>
        <source>5 GHz</source>
        <translation>5 GHz</translation>
    </message>
    <message>
        <source>MTU (1280-9000)</source>
        <translation>MTU (1280-9000)</translation>
    </message>
</context>
<context>
    <name>SectionGeneric</name>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Nazwa (SSID)</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Wymagane</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Połącz automatycznie</translation>
    </message>
</context>
<context>
    <name>SectionIPv4</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Gotowe</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Edytuj</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Wyłączone</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ręcznie</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatycznie</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Metoda</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Zastosuj tylko w wybranych zasobach</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Adres IP</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Nieprawidłowy adres IP</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Maska sieci</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brama sieciowa</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Nieprawidłowa maska sieci</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Nieprawidłowa brama sieciowa</translation>
    </message>
    <message>
        <source>Duplicate IP address</source>
        <translation>Zduplikowany adres IP</translation>
    </message>
</context>
<context>
    <name>SectionIPv6</name>
    <message>
        <source>Disabled</source>
        <translation>Wyłączone</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ręcznie</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignoruj</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatycznie</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Gotowe</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Edytuj</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Metoda</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Zastosuj tylko w wybranych zasobach</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Adres IP</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Nieprawidłowy adres IP</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefiks</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brama sieciowa</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Nieprawidłowa maska sieci</translation>
    </message>
    <message>
        <source>Duplicate IP address</source>
        <translation>Zduplikowany adres IP</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Nieprawidłowa brama sieciowa</translation>
    </message>
</context>
<context>
    <name>SectionPPP</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Użyj MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-bitowe MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stanowy MPPE</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Odrzuć uwierzytelnienie EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Odrzuć uwierzytelnienie PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Odrzuć uwierzytelnienie CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Odrzuć uwierzytelnienie MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Odrzuć uwierzytelnienie MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Brak kompresji danych BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Brak kompresji danych Deflate</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Brak kompresji nagłówka TCP</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Wyślij pakiety echa PPP</translation>
    </message>
</context>
<context>
    <name>SectionPPPOE</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nazwa użytkownika</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Wymagane</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Usługa</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
</context>
<context>
    <name>SectionSecret</name>
    <message>
        <source>Security</source>
        <translation>Bezpieczeństwo</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>Tunelowany TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>Zabezpieczony EAP</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Brak</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Enterprise</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>Uwierzytelnienie EAP</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Tożsamość</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Wymagane</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opcje hasła</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Zapisz dla tego użytkownika</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Zapisz dla wszystkich użytkowników</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Zawsze pytaj</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Klucz</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Hasło prywatne</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Uwierzytelnienie</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Klucz współdzielony</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Otwarty system</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Klucz prywatny</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>Anonimowe ID</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Udostępnianie</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Wyłączone</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anonimowo</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Uwierzytelnione</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Oba</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>Plik PAC</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certyfikat CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certyfikat użytkownika</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>Wersja PEAP</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatycznie</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Wersja 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Wersja 1</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Uwierzytelnienie wewnętrzne</translation>
    </message>
</context>
<context>
    <name>SectionVPN</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>Wszystkie pliki (*)</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Wymagane</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Nieprawidłowa brama sieciowa</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brama sieciowa</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certyfikat CA</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Zezwól na trojana Cisco Secure Desktop</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>Skrypt CSD</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Typ uwierzytelnienia</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Klucz prywatny</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>Agent SSH</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Karta inteligentna</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Klucz PSK</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certyfikat użytkownika</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nazwa użytkownika</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Użyj FSID jako hasła klucza</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Certyfikaty (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Certyfikaty z hasłem (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Klucz stały</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opcje hasła</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Zapytaj</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Niewymagane</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Hasło prywatne</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Dostosuj kierunek klucza</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Kierunek klucza</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>Zdalne IP</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>Lokalne IP</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>Domena NT</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Poproś o wewnętrzny adres IP</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Wymuszenie UDP Encapsulation</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Użyj kompresji IP</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Włącz propozycje niestandardowych szyfrów</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Nazwa grupy</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Hasło grupy</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Użyj uwierzytelnienia hybrydowego</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>Plik CA</translation>
    </message>
    <message>
        <source>VPN PPP</source>
        <translation>PPP VPN</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Użyj MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Bezpieczeństwo</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Wszystkie dostępne (domyślnie)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bitowe (mniej bezpieczne)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bitowe (najbardziej bezpieczne)</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stanowy MPPE</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Odrzuć uwierzytelnienie EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Odrzuć uwierzytelnienie PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Odrzuć uwierzytelnienie CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Odrzuć uwierzytelnienie MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Odrzuć uwierzytelnienie MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Brak kompresji danych BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Brak kompresji danych Deflate</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Brak kompresji nagłówka TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Brak Protocol Field Compression</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Brak kompresji adresu/kontroli</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Wyślij pakiety echa PPP</translation>
    </message>
    <message>
        <source>VPN IPsec</source>
        <translation>IPsec VPN</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Włącz IPsec</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>ID grupy</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Algorytmy Phase1</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Algorytmy Phase2</translation>
    </message>
    <message>
        <source>VPN Advanced</source>
        <translation>Zaawansowane ust. VPN</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Dostosuj port bramy sieciowej</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Port bramy sieciowej</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Dostosuj interwał negocjacji</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Interwał negocjacji</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Użyj kompresji danych LZO</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Użyj połączenia TCP</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Użyj urządzenia TAP</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Dostosuj tunel MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Dostosuj rozmiar fragmentu UDP</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>Rozmiar fragmentu UDP</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Ogranicz tunel TCP MSS</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Losowo wybieraj zdalnych hostów</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Domena</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Dostawca</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (domyślnie)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Wersja</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Szyfrowanie</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Bezpieczne (domyślnie)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Słabe</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Brak</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>Tryb NAT Traversal</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T gdy dostępne (domyślnie)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T zawsze</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Wyłączone</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>Grupa IKE DH</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH Grupa 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH Grupa 2 (domyślnie)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH Grupa 5</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Forward Secrecy</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Serwer (domyślnie)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH Grupa 2</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Port lokalny</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Wyłącz wykrywanie martwych peerów</translation>
    </message>
    <message>
        <source>VPN Security</source>
        <translation>Bezpieczeństwo VPN</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Szyfrowanie</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Domyślny</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>Uwierzytelnienie HMAC</translation>
    </message>
    <message>
        <source>RSA MD-4</source>
        <translation>RSA MD-4</translation>
    </message>
    <message>
        <source>MD-5</source>
        <translation>MD-5</translation>
    </message>
    <message>
        <source>SHA-1</source>
        <translation>SHA-1</translation>
    </message>
    <message>
        <source>SHA-224</source>
        <translation>SHA-224</translation>
    </message>
    <message>
        <source>SHA-256</source>
        <translation>SHA-256</translation>
    </message>
    <message>
        <source>SHA-384</source>
        <translation>SHA-384</translation>
    </message>
    <message>
        <source>SHA-512</source>
        <translation>SHA-512</translation>
    </message>
    <message>
        <source>RIPEMD-160</source>
        <translation>RIPEMD-160</translation>
    </message>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN Proxy</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Typ proxy</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP serwera</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Ponawiaj nieustannie, gdy wystąpi błąd</translation>
    </message>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>Uwierzytelnienie VPN TLS</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Weryfikacja tożsamości</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Typ zdalnego certyfikatu</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Klient</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Serwer</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Plik klucza</translation>
    </message>
    <message>
        <source>MTU (1280-9000)</source>
        <translation>MTU (1280-9000)</translation>
    </message>
</context>
<context>
    <name>SystemProxyConfigItem</name>
    <message>
        <source>Optional</source>
        <translation>Opcjonalne</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Authentication is required</source>
        <translation>Wymagane jest uwierzytelnienie</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nazwa użytkownika</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Wymagane</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
</context>
<context>
    <name>dde::network::NetAirplaneModeTipsItem</name>
    <message>
        <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>Najpierw wyłącz &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Tryb samolotowy&lt;/a&gt;, aby połączyć się z siecią bezprzewodową</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerPrivate</name>
    <message>
        <source>IP conflict</source>
        <translation>Konflikt IP</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Sieć</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerThreadPrivate</name>
    <message>
        <source>Wired Connection %1</source>
        <translation>Połączenie przewodowe %1</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>Połączenie PPPoE %1</translation>
    </message>
    <message>
        <source>Connecting &quot;%1&quot;</source>
        <translation>Łączenie z &quot;%1&quot;</translation>
    </message>
    <message>
        <source>&quot;%1&quot; connected</source>
        <translation>&quot;%1&quot; połączono</translation>
    </message>
    <message>
        <source>&quot;%1&quot; disconnected</source>
        <translation>&quot;%1&quot; rozłączono</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
        <translation>Nie można połączyć się z &quot;%1&quot;, sprawdź router lub kabel sieciowy.</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
        <translation>Nie można połączyć się z &quot;%1&quot;, przybliż się do routera bezprzewodowego</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
        <translation>Połączenie nieudane, nie można połączyć się z &quot;%1&quot;, błędne hasło</translation>
    </message>
    <message>
        <source>Password is required to connect &quot;%1&quot;</source>
        <translation>Wymagane jest hasło, aby połączyć się z &quot;%1&quot;</translation>
    </message>
    <message>
        <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
        <translation>Nie można znaleźć sieci WLAN 802.11 &quot;%1&quot;</translation>
    </message>
    <message>
        <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
        <translation>Aby połączyć się z &quot;%1&quot;, skonfiguruj informacje uwierzytelniające</translation>
    </message>
</context>
<context>
    <name>dde::network::NetSystemProxyControlItem</name>
    <message>
        <source>System Proxy</source>
        <translation>Proxy systemowe</translation>
    </message>
</context>
<context>
    <name>dde::network::NetVPNTipsItem</name>
    <message>
        <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
        <translation>Konfiguracja VPN jest nieprawidłowa lub wystąpił błąd połączenia. &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;Przejdź do Centrum kontroli&lt;/a&gt;, aby zdiagnozować problem.</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWiredControlItem</name>
    <message>
        <source>Wired Network</source>
        <translation>Sieć przewodowa</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessControlItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Sieć bezprzewodowa</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessHiddenItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Połącz z siecią ukrytą</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessMineItem</name>
    <message>
        <source>My Networks</source>
        <translation>Moje sieci</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessOtherItem</name>
    <message>
        <source>Other Networks</source>
        <translation>Inne sieci</translation>
    </message>
</context>
<context>
    <name>network</name>
    <message>
        <source>Network</source>
        <translation>Sieć</translation>
    </message>
</context>
<context>
    <name>networkMain</name>
    <message>
        <source>Connection settings</source>
        <translation>Ustawienia sieci</translation>
    </message>
    <message>
        <source>Related Settings</source>
        <translation>Powiązane ustawienia</translation>
    </message>
</context>
</TS>